Struct frui::druid_shell::piet::HitTestPoint
[−]Expand description
Result of hit testing a point in a TextLayout.
This type is returned by TextLayout::hit_test_point.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.idx: usizeThe index representing the grapheme boundary closest to the Point.
is_inside: boolWhether or not the point was inside the bounds of the layout object.
A click outside the layout object will still resolve to a position in the text; for instance a click to the right edge of a line will resolve to the end of that line, and a click below the last line will resolve to a position in that line.