Struct frui::druid_shell::FileDialogToken
[−]pub struct FileDialogToken(_);Expand description
A token that uniquely identifies a file dialog request.
Implementations
impl FileDialogToken
impl FileDialogToken
pub const INVALID: FileDialogToken = FileDialogToken(0)
pub const INVALID: FileDialogToken = FileDialogToken(0)
A token that does not correspond to any file dialog.
pub fn next() -> FileDialogToken
pub fn next() -> FileDialogToken
Create a new token.
pub const fn from_raw(id: u64) -> FileDialogToken
pub const fn from_raw(id: u64) -> FileDialogToken
Create a new token from a raw value.