Struct frui::prelude::FontWeight
[−]pub struct FontWeight(_);Expand description
A font weight, represented as a value in the range 1..=1000.
This is based on the CSS font-weight property. In general, you should
prefer the constants defined on this type, such as FontWeight::REGULAR or
FontWeight::BOLD.
Implementations
impl FontWeight
impl FontWeight
pub const THIN: FontWeight = FontWeight(100)
pub const HAIRLINE: FontWeight = FontWeight::THIN
pub const EXTRA_LIGHT: FontWeight = FontWeight(200)
pub const LIGHT: FontWeight = FontWeight(300)
pub const REGULAR: FontWeight = FontWeight(400)
pub const NORMAL: FontWeight = FontWeight::REGULAR
pub const MEDIUM: FontWeight = FontWeight(500)
pub const SEMI_BOLD: FontWeight = FontWeight(600)
pub const BOLD: FontWeight = FontWeight(700)
pub const EXTRA_BOLD: FontWeight = FontWeight(800)
pub const BLACK: FontWeight = FontWeight(900)
pub const HEAVY: FontWeight = FontWeight::BLACK
pub const EXTRA_BLACK: FontWeight = FontWeight(950)
pub fn new(raw: u16) -> FontWeight
pub fn new(raw: u16) -> FontWeight
Create a new FontWeight with a custom value.
Values will be clamped to the range 1..=1000.