Enum frui::druid_shell::WindowLevel
[−]pub enum WindowLevel {
AppWindow,
Tooltip,
DropDown,
Modal,
}Expand description
Levels in the window system - Z order for display purposes. Describes the purpose of a window and should be mapped appropriately to match platform conventions.
Variants
AppWindow
A top level app window.
Tooltip
A window that should stay above app windows - like a tooltip
DropDown
A user interface element such as a dropdown menu or combo box
Modal
A modal dialog